@@ -17,7 +17,7 @@
 #'
 #' iris_tbl %>%
 #'   select(-Species) %>%
-#'   ml_bisecting_kmeans(k = 4 , Species ~ .)
+#'   ml_bisecting_kmeans(k = 4, Species ~ .)
 #' }
 #'
 #' @export
@@ -127,9 +127,11 @@ new_ml_bisecting_kmeans <- function(jobj) {
 
 new_ml_bisecting_kmeans_model <- function(jobj) {
   has_summary <- tryCatch(invoke(jobj, "hasSummary"),
-                          error = function(e) FALSE)
-  summary <- if (has_summary)
+    error = function(e) FALSE
+  )
+  summary <- if (has_summary) {
     new_ml_bisecting_kmeans_summary(invoke(jobj, "summary"))
+  }
 
   new_ml_clustering_model(
     jobj,
@@ -138,18 +140,21 @@ new_ml_bisecting_kmeans_model <- function(jobj) {
         lapply(invoke, "toArray")
     ),
     compute_cost = function(dataset) {
-      if (is_required_spark(jobj, "2.4.0"))
+      if (is_required_spark(jobj, "2.4.0")) {
         warning("`compute_cost()` has been deprecated since Spark 2.4.0.", call. = FALSE)
+      }
       invoke(jobj, "computeCost", spark_dataframe(dataset))
     },
     summary = summary,
-    class = "ml_bisecting_kmeans_model")
+    class = "ml_bisecting_kmeans_model"
+  )
 }
 
 new_ml_bisecting_kmeans_summary <- function(jobj) {
   bisecting_kmeans_summary <- new_ml_clustering_summary(
     jobj,
-    class = "ml_bisecting_kmeans_summary")
+    class = "ml_bisecting_kmeans_summary"
+  )
 
   if (is_required_spark(jobj, "3.0.0")) {
     bisecting_kmeans_summary[["training_cost"]] <- invoke(jobj, "trainingCost")
