@@ -19,7 +19,8 @@ class WorkerContext(
   timeZoneId: String,
   schema: org.apache.spark.sql.types.StructType,
   options: Map[String, String],
-  barrier: Map[String, Any]) {
+  barrier: Map[String, Any],
+  partitionIndex: Int) {
 
   private var result: Array[Row] = Array[Row]()
   private var sourceArray: Option[Array[Row]] = None
@@ -117,4 +118,8 @@ class WorkerContext(
   def getBarrier() : Map[String, Any] = {
     barrier
   }
+
+  def getPartitionIndex() : Int = {
+    partitionIndex
+  }
 }
